==> slothpy-0.1.14.tar.gz: slothpy-0.1.14/README.md <==
<h1 align="center">
<img src="https://raw.githubusercontent.com/MTZ-dev/slothpy/main/doc/source/_static/slothpy_3.png" width="300">
</h1><br>

[![PyPI Downloads](https://img.shields.io/pypi/dm/slothpy.svg?label=PyPI%20downloads)](
https://pypi.org/project/slothpy/)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![GitHub Releases](https://img.shields.io/github/release-pre/MTZ-dev/slothpy.svg)](https://github.com/MTZ-dev/slothpy/releases)
[![Stack Overflow](https://img.shields.io/badge/stackoverflow-Ask%20questions-blue.svg)](
https://stackoverflow.com/questions/tagged/slothpy)
[![Journal Paper](https://img.shields.io/badge/DOI-your-paper-doi-blue)](
https://doi.org/your-paper-doi)

SlothPy is a comprehensive package for computational molecular magnetism.

- **Website:** [your-website](https://your-website)
- **Documentation:** [link-to-docs](https://link-to-docs)
- **E-mail the author:** [your-mailing-list](mikolaj.zychowicz@uj.edu.pl)
- **PyPI:** [PyPI Repository](https://pypi.org/project/slothpy/)
- **Source code:** [GitHub](https://github.com/MTZ-dev/slothpy)
- **Bug reports:** [GitHub Issues](https://github.com/MTZ-dev/slothpy/issues)
- **Requests** [GitHub Pull Requests](https://github.com/MTZ-dev/slothpy/pulls)



# SlothPy

SlothPy aims to become a comprehensive software package for computational molecular magnetism. It is designed to provide flexible, interactive computing environment for researchers in the field.

## Features

- Interactive scripting via Jupyter Notebooks or terminal.
- Customizable workflows with JIT compilation and parallelism for performance.
- Extensible to integrate with MOLCAS, ORCA, and other chemistry software.
- Visual tools for data analysis and interpretation.

## Installation

```bash
pip install slothpy
```

For detailed installation instructions, please refer to the [Installation Guide](link-to-docs).

## Usage

Start with importing SlothPy:

```python
import slothpy as slt
```

and see your [How to Start](link-to-how-to-start) for various tutorials.

## Documentation

For comprehensive guides and tutorials, visit our [documentation](link-to-docs).

## How to Cite

If you use SlothPy in your research, please cite it as follows:

```
Authors. (Year). "Title of the Paper." Journal Name, Volume(Issue), pages. DOI: DOI Number
```

## Contributing

We welcome contributions in the form of issue reports, pull requests and suggestions send directly via e-mail Please see our [About section](link-to-about). 

## License

SlothPy is distributed under the GPL-3.0 license. See the LICENSE file for more information.

## Contact

For questions and feedback, please contact mikolaj.zychowicz@uj.edu.pl.

==> slothpy-0.2.0.tar.gz: slothpy-0.2.0/README.md <==
<h1 align="center">
<img src="https://raw.githubusercontent.com/MTZ-dev/slothpy/main/doc/source/_static/slothpy_3.png" width="300">
</h1><br>

[![PyPI Downloads](https://img.shields.io/pypi/dm/slothpy.svg?label=PyPI%20downloads)](
https://pypi.org/project/slothpy/)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![GitHub Releases](https://img.shields.io/github/release-pre/MTZ-dev/slothpy.svg)](https://github.com/MTZ-dev/slothpy/releases)
[![Stack Overflow](https://img.shields.io/badge/stackoverflow-Ask%20questions-blue.svg)](
https://stackoverflow.com/questions/tagged/slothpy)
[![Journal Paper](https://img.shields.io/badge/DOI-your-paper-doi-blue)](
https://doi.org/your-paper-doi)

SlothPy is a comprehensive package for computational molecular magnetism.

- **Website:** [your-website](https://your-website)
- **Documentation:** [link-to-docs](https://link-to-docs)
- **E-mail the author:** [your-mailing-list](mikolaj.zychowicz@uj.edu.pl)
- **PyPI:** [PyPI Repository](https://pypi.org/project/slothpy/)
- **Source code:** [GitHub](https://github.com/MTZ-dev/slothpy)
- **Bug reports:** [GitHub Issues](https://github.com/MTZ-dev/slothpy/issues)
- **Requests** [GitHub Pull Requests](https://github.com/MTZ-dev/slothpy/pulls)



# SlothPy

SlothPy aims to become a comprehensive software package for computational molecular magnetism. It is designed to provide flexible, interactive computing environment for researchers in the field.

## Features

- Interactive scripting via Jupyter Notebooks or terminal.
- Customizable workflows with JIT compilation and parallelism for performance.
- Extensible to integrate with MOLCAS, ORCA, and other chemistry software.
- Visual tools for data analysis and interpretation.

## Installation

```bash
pip install slothpy
```

For detailed installation instructions, please refer to the [Installation Guide](link-to-docs).

## Usage

Start with importing SlothPy:

```python
import slothpy as slt
```

and see your [How to Start](link-to-how-to-start) for various tutorials.

## Documentation

For comprehensive guides and tutorials, visit our [documentation](link-to-docs).

## How to Cite

If you use SlothPy in your research, please cite it as follows:

```
Authors. (Year). "Title of the Paper." Journal Name, Volume(Issue), pages. DOI: DOI Number
```

## Contributing

We welcome contributions in the form of issue reports, pull requests and suggestions send directly via e-mail. Please see our [About section](link-to-about). 

## License

SlothPy is distributed under the GPL-3.0 license. See the LICENSE file for more information.

## Contact

For questions and feedback, please contact mikolaj.zychowicz@uj.edu.pl.
